You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ma...@apache.org on 2014/05/03 13:45:22 UTC

svn commit: r1592186 - /openoffice/ooo-site/trunk/content/download/test/download_droplist.js

Author: marcus
Date: Sat May  3 11:45:21 2014
New Revision: 1592186

URL: http://svn.apache.org/r1592186
Log:
Renamed function to 'isLangSupported()' to reflect its purpose better

Modified:
    openoffice/ooo-site/trunk/content/download/test/download_droplist.js

Modified: openoffice/ooo-site/trunk/content/download/test/download_droplist.js
URL: http://svn.apache.org/viewvc/openoffice/ooo-site/trunk/content/download/test/download_droplist.js?rev=1592186&r1=1592185&r2=1592186&view=diff
==============================================================================
--- openoffice/ooo-site/trunk/content/download/test/download_droplist.js (original)
+++ openoffice/ooo-site/trunk/content/download/test/download_droplist.js Sat May  3 11:45:21 2014
@@ -1,25 +1,25 @@
 /*
  * Overview of all functions defined below
  * ---------------------------------------
  * function init          ()
  * function initVars      ()
  * function alertDbg      ( function_name )
  * function getLanguage   ()
  * function fillOSSel     ()
  * function fillLangSel   ()
  * function fillVerSel    ()
  * function getOSSel      ()
  * function getLangSel    ()
  * function getVerSel     ()
  * function resetSel      ()
  * function showPopup     ( target_url )
  * function hasMirrorLink ()
  * function getLink       ( rel_mode )
  * function getLinkSel    ()
  * function getPlatform   ()
  * function getFilename   ( ver )
  * function getFilesize   ()
  * function openItem      ( itemid, uri )
  */
 
 /*
@@ -86,6 +86,7 @@ function alertDbg( function_name ) {
 	+ "RELEASE_MATRIX_PLATFORM_POS_LP: "	+ "\t"			+ RELEASE_MATRIX_PLATFORM_POS_LP	+ "\n"
 	+ "RELEASE_MATRIX_PLATFORM: "		+ "\t\t"		+ RELEASE_MATRIX_PLATFORM		+ "\n"
 	+ "RELEASE_MATRIX_LANG: "		+ "\t\t\t"		+ RELEASE_MATRIX_LANG			+ "\n"
+	+ "isLangSupported(): "			+ "\t\t\t"		+ RELEASE_MATRIX_LANG[ 1 ]		+ "\n"
 	+ "UI_PLATFORM: "			+ "\t\t\t\t\t"		+ UI_PLATFORM				+ "\n"
 	+ "URL_PLATFORM: "			+ "\t\t\t\t\t"		+ URL_PLATFORM				+ "\n"
 	+ "OLD_PLATFORM: "			+ "\t\t\t\t"		+ OLD_PLATFORM				+ "\n"
@@ -467,7 +468,7 @@ function showPopup( target_url ) {
  * Depends on array-list and "languages.js"
  * Depends on array-list and "release_matrix.js"
  */
-function hasMirrorLink() {
+function isLangSupported() {
 	// Check the flag in "languages.js", 'y' -> provide download link, 'n' -> redirect to alternative webpage.
 	// Check the flag in "release_matrix.js", 'y' -> provide download link, 'n' -> redirect to alternative webpage.
 //	if ( LANG_ARRAY[ 3 ] == 'y' ) {
@@ -493,12 +494,12 @@ function getLink( rel_mode ) {
 
 	getLanguage();
 	getPlatform();
-	if ( hasMirrorLink() ) {
+	if ( isLangSupported() ) {
 		getFilesize();
 	}
 
 	// If language is supported, provide a download link. 
-	if ( hasMirrorLink() ) {
+	if ( isLangSupported() ) {
 		// If platform is too old, provide a general download link to the archive.
 		if ( OLD_PLATFORM ) {
 			// If platform is 'Mac OS X <= 10.6', provide a download link with previous AOO version.
@@ -1,25 +1,25 @@
 /*
  * Overview of all functions defined below
- * ---------------------------------------
- * function init          ()
- * function initVars      ()
- * function alertDbg      ( function_name )
- * function getLanguage   ()
- * function fillOSSel     ()
- * function fillLangSel   ()
- * function fillVerSel    ()
- * function getOSSel      ()
- * function getLangSel    ()
- * function getVerSel     ()
- * function resetSel      ()
- * function showPopup     ( target_url )
- * function hasMirrorLink ()
- * function getLink       ( rel_mode )
- * function getLinkSel    ()
- * function getPlatform   ()
- * function getFilename   ( ver )
- * function getFilesize   ()
- * function openItem      ( itemid, uri )
+ * ------------------------------------------
+ * function init            ()
+ * function initVars        ()
+ * function alertDbg        ( function_name )
+ * function getLanguage     ()
+ * function fillOSSel       ()
+ * function fillLangSel     ()
+ * function fillVerSel      ()
+ * function getOSSel        ()
+ * function getLangSel      ()
+ * function getVerSel       ()
+ * function resetSel        ()
+ * function showPopup       ( target_url )
+ * function isLangSupported ()
+ * function getLink         ( rel_mode )
+ * function getLinkSel      ()
+ * function getPlatform     ()
+ * function getFilename     ( ver )
+ * function getFilesize     ()
+ * function openItem        ( itemid, uri )
  */
 